@@ -1,15 +1,7 @@
 #' @title Assessing the performance of acoustic distance measurements
 #'
 #' @description \code{compare_methods} creates graphs to visually assess performance of acoustic distance measurements
-#' @usage compare_methods(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 512, ovlp = 90,
-#' res = 150, n = 10, length.out = 30,
-#' methods = NULL,
-#' it = "jpeg", parallel = 1, path = NULL, sp = NULL, custom1 = NULL,
-#' custom2 = NULL, pb = TRUE, grid = TRUE,  clip.edges = TRUE,
-#' threshold = 15, na.rm = FALSE, scale = FALSE, pal = reverse.gray.colors.2,
-#' img = TRUE, ...)
-#' @param X 'selection_table' object or data frame with results from \code{\link{auto_detec}}
-#' function, or any data frame with columns for sound file name (sound.files),
+#' @param X 'selection_table' object or data frame with columns for sound file name (sound.files),
 #' selection number (selec), and start and end time of signal (start and end).
 #' Default \code{NULL}.
 #' @param flim A numeric vector of length 2 for the frequency limit in kHz of
@@ -44,7 +36,6 @@
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
 #' @param path Character string containing the directory path where the sound files are located.
 #' If \code{NULL} (default) then the current working directory is used.
-#' @param sp DEPRECATED.
 #' @param custom1 Data frame containing user parameters. The data frame must have 4 columns: the first 2 columns are 'sound.files'
 #' and "selec' columns as in 'X', the other 2 (columns 3 and 4) are
 #' 2 numeric columns to be used as the 2 parameters representing custom measurements. If the data has more than 2 parameters try using PCA (i.e. \code{\link[stats]{prcomp}} function)to summarize it in 2 dimensions before using it as an input. Default is \code{NULL}.
@@ -162,56 +153,68 @@
 #' seewave package to create spectrograms.
 # last modification on mar-13-2018 (MAS)
 
-compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 512, ovlp = 90,
-                            res = 150, n = 10, length.out = 30, methods = NULL,
-                            it = "jpeg", parallel = 1, path = NULL, sp = NULL, custom1 = NULL, custom2 = NULL, pb = TRUE, grid = TRUE,
-                            clip.edges = TRUE, threshold = 15, na.rm = FALSE, scale = FALSE,
-                            pal = reverse.gray.colors.2, img = TRUE, ...) {
-  # define number of steps in analysis to print message
-  steps <- c(current = 1, total = 0)
+
+compare_methods <- function(X = NULL,
+                            flim = NULL,
+                            bp = NULL,
+                            mar = 0.1,
+                            wl = 512,
+                            ovlp = 90,
+                            res = 150,
+                            n = 10,
+                            length.out = 30,
+                            methods = NULL,
+                            it = "jpeg",
+                            parallel = 1,
+                            path = NULL,
+                            custom1 = NULL,
+                            custom2 = NULL,
+                            pb = TRUE,
+                            grid = TRUE,
+                            clip.edges = TRUE,
+                            threshold = 15,
+                            na.rm = FALSE,
+                            scale = FALSE,
+                            pal = reverse.gray.colors.2,
+                            img = TRUE,
+                            ...
+) {
 
   if (pb) {
-    steps[2] <- 3
-    if (any(methods == "XCORR")) steps[2] <- steps[2] + 1
-    if (!is.null(custom1)) steps[2] <- steps[2] - 1
-    if (!is.null(custom2)) steps[2] <- steps[2] - 1
-
-    # for functions with no internal step count
-    total.steps <- steps[2]
-    current.step <- 1
-
-    # set internally
-    options("int_warbleR_steps" = steps)
-
-    on.exit(options("int_warbleR_steps" = c(current = 0, total = 0)), add = TRUE)
+    total <- 3
+    if (any(methods == "XCORR")) total <- total + 1
+    if (!is.null(custom1)) total <- total - 1
+    if (!is.null(custom2)) total <- total - 1
+    
+    .update_progress(total = total)
   }
-
+  
   #### set arguments from options
   # get function arguments
   argms <- methods::formalArgs(compare_methods)
-
+  
   # get warbleR options
   opt.argms <- if (!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
-
+  
   options(warn = -1)
   on.exit(options(warn = 0), add = TRUE)
-
+  
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
-
+  
   # get arguments set in the call
   call.argms <- as.list(base::match.call())[-1]
-
+  
   # remove arguments in options that are in call
   opt.argms <- opt.argms[!names(opt.argms) %in% names(call.argms)]
-
+  
   # set options left
   if (length(opt.argms) > 0) {
     for (q in seq_len(length(opt.argms))) {
       assign(names(opt.argms)[q], opt.argms[[q]])
     }
   }
-
+  
   # check path to working directory
   if (is.null(path)) {
     path <- getwd()
@@ -220,10 +223,10 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
   } else {
     path <- normalizePath(path)
   }
-
+  
   # if X is not a data frame
   if (!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
-
+  
   # check basic columns in X
   if (!all(c(
     "sound.files", "selec",
@@ -234,11 +237,11 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       "start", "end"
     ) %in% colnames(X))], collapse = ", "), "column(s) not found in data frame"))
   }
-
+  
   # if parallel is not numeric
   if (!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1")
   if (any(!(parallel %% 1 == 0), parallel < 1)) stop("'parallel' should be a positive integer")
-
+  
   # methods
   if (is.null(methods)) {
     if (is.null(custom1) & is.null(custom2)) stop("'methods' or custom data should be provided") else methods <- c(NA, NA)
@@ -249,8 +252,8 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       stop(paste(setdiff(methods, c("XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC")), "is (are) not valid method(s)"))
     }
   }
-
-
+  
+  
   # if flim is not vector or length!=2 stop
   if (!is.null(flim)) {
     if (!is.vector(flim)) {
@@ -259,7 +262,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       if (!length(flim) == 2) stop("'flim' must be a numeric vector of length 2")
     }
   }
-
+  
   # if bp is not vector or length!=2 stop
   if (!is.null(bp)) {
     if (!is.vector(bp)) {
@@ -268,7 +271,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       if (!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")
     }
   }
-
+  
   # if wl is not vector or length!=1 stop
   if (is.null(wl)) {
     stop("'wl' must be a numeric vector of length 1")
@@ -279,7 +282,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       if (!length(wl) == 1) stop("'wl' must be a numeric vector of length 1")
     }
   }
-
+  
   # if res is not vector or length!=1 stop
   if (is.null(res)) {
     stop("'res' must be a numeric vector of length 1")
@@ -290,24 +293,24 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       if (!length(res) == 1) stop("'res' must be a numeric vector of length 1")
     }
   }
-
+  
   # if there are NAs in start or end stop
   if (any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")
-
+  
   # if any start higher than end stop
   if (any(X$end - X$start <= 0)) stop(paste("Start is higher than or equal to end in", length(which(X$end - X$start <= 0)), "case(s)"))
-
+  
   # if any selections longer than 20 secs stop
   if (any(X$end - X$start > 20)) stop(paste(length(which(X$end - X$start > 20)), "selection(s) longer than 20 sec"))
-
+  
   # If n is not numeric
   if (!is.numeric(n)) stop("'n' must be a numeric vector of length 1")
   if (any(!(n %% 1 == 0), n < 1)) stop("'n' should be a positive integer")
-
+  
   # If length.out is not numeric
   if (!is.numeric(length.out)) stop("'length.out' must be a numeric vector of length 1")
   if (any(!(length.out %% 1 == 0), length.out < 1)) stop("'length.out' should be a positive integer")
-
+  
   # return warning if not all sound files were found
   if (!is_extended_selection_table(X)) {
     fs <- list.files(path = path, pattern = "\\.wav$|\\.wac$|\\.mp3$|\\.flac$", ignore.case = TRUE)
@@ -317,7 +320,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         "sound file(s) not found"
       ))
     }
-
+    
     # count number of sound files in working directory and if 0 stop
     d <- which(X$sound.files %in% fs)
     if (length(d) == 0) {
@@ -326,17 +329,14 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       X <- X[d, ]
     }
   }
-
-  # check sp data frame
-  if (!is.null(sp)) warning2(x = "'sp' has been deprecated and will be ignored. Use 'custom1' instead")
-
+  
   # check custom1 data frame
   if (!is.null(custom1)) {
     if (!is.data.frame(custom1)) stop("'custom1' must be a data frame")
     if (nrow(custom1) != nrow(X)) stop("'custom1' must have the same number of selections than X")
     if (ncol(custom1) != 4) stop("'custom1' must have 4 columns")
     if (!all(c("sound.files", "selec") %in% names(custom1))) stop("'sound.files' or 'selec' columns missing in 'custom1'")
-
+    
     # over write method names
     if (is.null(custom2)) {
       methods[2] <- "custom1"
@@ -344,7 +344,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
       methods[1] <- "custom1"
     }
   }
-
+  
   # check custom2 data frame
   if (!is.null(custom2)) {
     if (!is.null(custom2) & is.null(custom1)) stop("please provide 'custom1' first")
@@ -352,175 +352,138 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
     if (nrow(custom2) != nrow(X)) stop("'custom1' must have the same number of selections than X")
     if (ncol(custom2) != 4) stop("'custom2' must have 4 columns")
     if (!all(c("sound.files", "selec") %in% names(custom2))) stop("'sound.files' or 'selec' columns missing in 'custom1'")
-
+    
     methods[2] <- "custom2"
   }
-
+  
   # if it argument is not "jpeg" or "tiff"
   if (!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))
-
+  
   # create empty list for method results
   bidims <- list()
-
+  
   if ("custom1" %in% methods) {
     if (anyNA(custom1)) stop("NAs were found in 'custom1'")
-
+    
     if (length(setdiff(paste(custom1$sound.files, custom1$selec), paste(X$sound.files, X$selec))) > 0) stop("some/all custom 1 'sound.files' and/or 'selec' values don't match with those in 'X'")
-
+    
     custom1 <- custom1[match(paste(custom1$sound.files, custom1$selec), paste(X$sound.files, X$selec)), ]
-
+    
     bidims[[length(bidims) + 1]] <- custom1[, 3:4]
   }
-
+  
   if ("custom2" %in% methods) {
     if (anyNA(custom2)) stop("NAs were found in 'custom2'")
-
+    
     if (length(setdiff(paste(custom2$sound.files, custom2$selec), paste(X$sound.files, X$selec))) > 0) stop("some/all custom 2 'sound.files' and/or 'selec' values don't match with those in 'X'")
-
-
+    
+    
     custom2 <- custom2[match(paste(X$sound.files, X$selec), paste(custom2$sound.files, custom2$selec)), ]
-
+    
     bidims[[length(bidims) + 1]] <- custom2[, 3:4]
   }
-
+  
   if ("XCORR" %in% methods) {
-    xcmat <- warbleR::cross_correlation(X, wl = wl, bp = bp, ovlp = ovlp, parallel = parallel, pb = pb, na.rm = na.rm, path = path, dens = NULL)
-
+    xcmat <- warbleR::cross_correlation(X, wl = wl, bp = bp, ovlp = ovlp, parallel = parallel, pb = pb, na.rm = na.rm, path = path)
+    
     MDSxcorr <- stats::cmdscale(1 - xcmat)
     MDSxcorr <- scale(MDSxcorr)
     bidims[[length(bidims) + 1]] <- MDSxcorr
-
+    
     # remove the ones that failed cross-corr
     if (na.rm) X <- X[paste(X$sound.files, X$selec, sep = "-") %in% rownames(MDSxcorr), ]
-    # update number of steps
-    current.step <- steps[1] <- steps[1] + 2
-    options("int_warbleR_steps" = steps)
-  }
-
+   }
+  
   if ("dfDTW" %in% methods) {
-    if (pb) {
-      message2(x = paste0("measuring dominant frequency contours (step ", current.step, " of ", total.steps, "):"), color = "black")
-    }
-
-
+    
     dtwmat <- warbleR::freq_ts(X,
-      wl = wl, flim = flim, ovlp = ovlp, img = FALSE, parallel = parallel, length.out = length.out,
-      pb = pb, clip.edges = clip.edges, threshold = threshold, path = path
+                               wl = wl, flim = flim, ovlp = ovlp, img = FALSE, parallel = parallel, length.out = length.out,
+                               pb = pb, clip.edges = clip.edges, threshold = threshold, path = path
     )
-
+    
     dtwmat <- dtwmat[, 3:ncol(dtwmat)]
-
+    
     if (scale) {
       dtwmat <- t(apply(dtwmat, 1, scale))
     }
-
+    
     dm <- dtw::dtwDist(dtwmat, dtwmat, method = "DTW")
-
+    
     MDSdtw <- stats::cmdscale(dm)
     MDSdtw <- scale(MDSdtw)
     bidims[[length(bidims) + 1]] <- MDSdtw
-
-    # update number of steps
-    current.step <- steps[1] <- steps[1] + 1
-    options("int_warbleR_steps" = steps)
   }
-
+  
   if ("ffDTW" %in% methods) {
-    if (pb) {
-      message2(x = paste0("measuring fundamental frequency contours (step ", current.step, " of ", total.steps, "):"), "black")
-    }
-
+ 
     dtwmat <- warbleR::freq_ts(X,
-      type = "fundamental", bp = bp, wl = wl, flim = flim, ovlp = ovlp, img = FALSE, parallel = parallel, length.out = length.out, ff.method = "seewave",
-      pb = pb, clip.edges = clip.edges, threshold = threshold, path = path
+                               type = "fundamental", bp = bp, wl = wl, flim = flim, ovlp = ovlp, img = FALSE, parallel = parallel, length.out = length.out, ff.method = "seewave",
+                               pb = pb, clip.edges = clip.edges, threshold = threshold, path = path
     )
-
+    
     dtwmat <- dtwmat[, 3:ncol(dtwmat)]
-
+    
     if (scale) {
       dtwmat <- t(apply(dtwmat, 1, scale))
     }
-
+    
     dm <- dtw::dtwDist(dtwmat, dtwmat, method = "DTW")
-
+    
     MDSdtw <- stats::cmdscale(dm)
     MDSdtw <- scale(MDSdtw)
     bidims[[length(bidims) + 1]] <- MDSdtw
-
-    # update number of steps
-    current.step <- steps[1] <- steps[1] + 1
-    options("int_warbleR_steps" = steps)
-  }
-
+    }
+  
   if ("SP" %in% methods) {
-    if (pb) {
-      message2(x = paste0("measuring spectral parameters (step ", current.step, " of ", total.steps, "):"), color = "black")
-    }
-
+    
     spmat <- warbleR::spectro_analysis(X, wl = wl, bp = bp, parallel = parallel, pb = pb, threshold = threshold, harmonicity = FALSE, path = path)
-
+    
     PCsp <- prcomp(scale(spmat[, 3:ncol(spmat)]), center = TRUE, scale. = TRUE, rank. = 2)$x
-
+    
     bidims[[length(bidims) + 1]] <- PCsp
-
-    # update number of steps
-    current.step <- steps[1] <- steps[1] + 1
-    options("int_warbleR_steps" = steps)
+    
   }
-
+  
   if ("SPharm" %in% methods) {
-    if (pb) {
-      message2(x = paste0("measuring spectral parameters + harmonicity (step ", current.step, " of ", total.steps, "):"), "black")
-    }
-
+    
     spmat <- warbleR::spectro_analysis(X, wl = wl, bp = bp, parallel = parallel, pb = pb, threshold = threshold, harmonicity = TRUE, path = path)
-
+    
     if (any(sapply(spmat, anyNA))) {
       spmat <- spmat[, !sapply(spmat, anyNA)]
       warning2("some NAs prdouced by SPharm, columns were removed")
     }
-
+    
     PCsp <- prcomp(scale(spmat[, 3:ncol(spmat)]), center = TRUE, scale. = TRUE, rank. = 2)$x
-
+    
     bidims[[length(bidims) + 1]] <- PCsp
-
-    # update number of steps
-    current.step <- steps[1] <- steps[1] + 1
-    options("int_warbleR_steps" = steps)
   }
-
+  
   if ("MFCC" %in% methods) {
-    if (pb) {
-      message2(x = paste0("measuring mel frequency cepstral coefficients (step ", current.step, " of ", total.steps, "):"), "black")
-    }
     mfcc <- warbleR::mfcc_stats(X, wl = wl, bp = bp, parallel = parallel, pb = pb, path = path)
-
+    
     if (any(sapply(mfcc, anyNA))) stop("NAs generated when calculated MFCC's, try a higher 'wl'")
-
+    
     PCmfcc <- prcomp(mfcc[, 3:ncol(mfcc)], center = TRUE, scale. = TRUE, rank. = 2)$x
-
+    
     bidims[[length(bidims) + 1]] <- PCmfcc
-
-    # update number of steps
-    current.step <- steps[1] <- steps[1] + 1
-    options("int_warbleR_steps" = steps)
+    
   }
-
+  
   # name matchs changing order to match order in whic methods are ran
   nms <- match(c("custom1", "custom2", "XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC"), methods)
-
+  
   # add names
   names(bidims) <- c("custom1", "custom2", "XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC")[!is.na(nms)]
-
+  
   #
   maxdist <- lapply(bidims, function(x) max(stats::dist(x)))
-
+  
   X$labels <- 1:nrow(X)
-
+  
   # maximum of 100 items for combinations
   smps <- sample(x = 1:nrow(X), size = ifelse(nrow(X) > 100, 100, nrow(X)))
   combs <- combn(smps, 4)
-
+  
   if (nrow(X) == 4) {
     n <- 1
     combs <- as.matrix(1:4)
@@ -529,9 +492,9 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
     n <- ncol(combs)
     message2(paste("Only", n, "possible combinations of signals"))
   }
-
+  
   if (nrow(X) > 4) combs <- as.data.frame(combs[, sample(seq_len(ncol(combs)), n)])
-
+  
   # create matrix for sppliting screen
   m <- rbind(
     c(0, 2.5 / 7, 3 / 10, 5 / 10), # 1
@@ -546,43 +509,43 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
     c(0, 3.5 / 7, 9 / 10, 10 / 10), # 10
     c(3.5 / 7, 1, 9 / 10, 10 / 10)
   ) # 11
-
+  
   # screen 1:4 for spectros
   # screen 5,6 for scatterplots
   # screen 7:9 for similarities/arrows
   # screen 10:11 method labels
-
+  
   comp.methFUN <- function(X, u, res, bidims, m, mar, flim) {
     rs <- combs[, u]
     X <- X[rs, ]
-
+    
     if (img) {
       img_wrlbr_int(filename = paste("comp.meth-", names(bidims)[1], "-", names(bidims)[2], "-", paste(X$labels, collapse = "-"), paste0(".", it), sep = ""), path = path, width = 16.25, height = 16.25, units = "cm", res = res)
     }
-
+    
     graphics::split.screen(m, erase = FALSE)
-
+    
     mxdur <- max(X$end - X$start) + mar * 2
-
+    
     # set colors for numbers in scatterplots and spectrograms
     col <- rep("gray40", nrow(bidims[[1]]))
-
+    
     col <- adjustcolor(col, alpha.f = 0.5)
-
+    
     col[rs] <- hcl(h = seq(15, 375, length = 4 + 1), l = 65, c = 100)[1:4]
-
+    
     col[rs] <- adjustcolor(col[rs], alpha.f = 0.8)
-
+    
     invisible(lapply(c(7:9, 1:4, 5:6, 10:11), function(x) {
       graphics::screen(x, new = FALSE)
       par(mar = rep(0, 4))
       if (x < 5) {
         r <- warbleR::read_sound_file(X = X, path = path, index = x, header = TRUE)
         tlim <- c((X$end[x] - X$start[x]) / 2 + X$start[x] - mxdur / 2, (X$end[x] - X$start[x]) / 2 + X$start[x] + mxdur / 2)
-
+        
         mar1 <- X$start[x] - tlim[1]
         mar2 <- mar1 + X$end[x] - X$start[x]
-
+        
         if (tlim[1] < 0) {
           tlim1.fix <- TRUE
           tlim[2] <- abs(tlim[1]) + tlim[2]
@@ -592,7 +555,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         } else {
           tlim1.fix <- FALSE
         }
-
+        
         if (tlim[2] > r$samples / r$sample.rate) {
           if (!tlim1.fix) {
             tlim[1] <- tlim[1] - (r$samples / r$sample.rate - tlim[2])
@@ -603,15 +566,15 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
             tlim[2] <- r$samples / r$sample.rate
           }
         }
-
+        
         if (is.null(flim)) {
           flim <- c(0, floor(r$sample.rate / 2000))
         }
-
+        
         if (flim[2] > floor(r$sample.rate / 2000)) flim[2] <- floor(r$sample.rate / 2000)
-
+        
         r <- warbleR::read_sound_file(X = X, path = path, index = x, from = tlim[1], to = tlim[2])
-
+        
         spectro_wrblr_int2(wave = r, f = r@samp.rate, flim = flim, wl = wl, ovlp = ovlp, axisX = FALSE, axisY = FALSE, tlab = FALSE, flab = FALSE, palette = pal, grid = grid, ...)
         box(lwd = 2)
         if (x == 1 | x == 3) {
@@ -623,7 +586,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
           abline(v = c(mar1, mar2), lty = 4, col = "gray")
         }
       }
-
+      
       # upper left
       if (x == 5) {
         plot(bidims[[1]], col = "white", xaxt = "n", yaxt = "n", xlim = c(min(bidims[[1]][, 1]) * 1.1, max(bidims[[1]][, 1]) * 1.1), ylim = c(min(bidims[[1]][, 2]) * 1.1, max(bidims[[1]][, 2]) * 1.1))
@@ -634,7 +597,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         cex[rs] <- 1.4
         text(bidims[[1]], labels = 1:nrow(bidims[[1]]), col = col, cex = cex, font = 2)
       }
-
+      
       # upper right
       if (x == 6) {
         plot(bidims[[2]], col = "white", xaxt = "n", yaxt = "n", xlim = c(min(bidims[[2]][, 1]) * 1.1, max(bidims[[2]][, 1]) * 1.1), ylim = c(min(bidims[[2]][, 2]) * 1.1, max(bidims[[2]][, 2]) * 1.1))
@@ -645,7 +608,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         cex[rs] <- 1.4
         text(bidims[[2]], labels = 1:nrow(bidims[[2]]), col = col, cex = cex, font = 2)
       }
-
+      
       # lower mid
       if (x == 8) {
         plot(0.5, xlim = c(0, 1), ylim = c(0, 1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
@@ -664,7 +627,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         text(0.3, 4.16 / 7, labels = round(stats::dist(bidims[[1]][rs[c(1, 4)], ]) / maxdist[[1]], 2), col = "black", font = 2, pos = 3)
         text(0.15, 4.4 / 7, labels = round(stats::dist(bidims[[2]][rs[c(1, 4)], ]) / maxdist[[2]], 2), col = "gray50", font = 2, pos = 1)
       }
-
+      
       # in between left
       if (x == 7) {
         plot(0.5, xlim = c(0, 1), ylim = c(0, 1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
@@ -674,7 +637,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         text(0.53, 0.5, labels = round(stats::dist(bidims[[1]][rs[c(1, 3)], ]) / maxdist[[1]], 2), col = "black", font = 2, pos = 2)
         text(0.47, 0.5, labels = round(stats::dist(bidims[[2]][rs[c(1, 3)], ]) / maxdist[[2]], 2), col = "gray50", font = 2, pos = 4)
       }
-
+      
       # in between right
       if (x == 9) {
         plot(0.5, xlim = c(0, 1), ylim = c(0, 1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
@@ -684,7 +647,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         text(0.53, 0.5, labels = round(stats::dist(bidims[[1]][rs[c(2, 4)], ]) / maxdist[[1]], 2), col = "black", font = 2, pos = 2)
         text(0.47, 0.5, labels = round(stats::dist(bidims[[2]][rs[c(2, 4)], ]) / maxdist[[2]], 2), col = "gray50", font = 2, pos = 4)
       }
-
+      
       # top (for method labels)
       if (x == 10) {
         plot(0.5, xlim = c(0, 1), ylim = c(0, 1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
@@ -693,7 +656,7 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
         text(0.5, 0.5, labels = names(bidims)[1], col = "black", font = 2, cex = 1.2)
         box(lwd = 4)
       }
-
+      
       if (x == 11) {
         plot(0.5, xlim = c(0, 1), ylim = c(0, 1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
         lim <- par("usr")
@@ -707,22 +670,24 @@ compare_methods <- function(X = NULL, flim = NULL, bp = NULL, mar = 0.1, wl = 51
     }
     on.exit(invisible(close.screen(all.screens = TRUE)))
   }
-
+  
   # save image files
   if (pb) {
-    message2(x = paste0("creating image files (step ", current.step, " of ", total.steps, "):"), "black")
+    reset_onexit <- .update_progress("creating image files", current = total, total = total)
+    
+      on.exit(expr = eval(parse(text = reset_onexit)), add = TRUE)
   }
-
+  
   # set clusters for windows OS
   if (Sys.info()[1] == "Windows" & parallel > 1) {
     cl <- parallel::makePSOCKcluster(getOption("cl.cores", parallel))
   } else {
     cl <- parallel
   }
-
+  
   a1 <- pblapply_wrblr_int(pbar = pb, X = seq_len(ncol(combs)), cl = cl, FUN = function(u) {
     comp.methFUN(X, u, res, bidims, m, mar, flim)
   })
-
+  
   return(NULL)
 }
