@@ -1,8 +1,6 @@
 #' Fix .wav files to allow importing them into R
 #'
 #' \code{fix_wavs} fixes sound files in .wav format so they can be imported into R.
-#' @usage fix_wavs(checksels = NULL, files = NULL, samp.rate = NULL, bit.depth = NULL,
-#'  path = NULL, mono = FALSE)
 #' @param checksels Data frame with results from \code{\link{check_sels}}. Default is \code{NULL}. If  both 'checksels' and 'files' are \code{NULL}
 #' then all files in 'path' are converted. Note that it only fixes/convert sound files in .wav format.
 #' @param files Character vector with the names of the .wav files to fix. Default is \code{NULL}. If  both 'checksels' and 'files'  are \code{NULL}
@@ -19,7 +17,7 @@
 #' sound files in a format that can be imported in R.
 #' @export
 #' @name fix_wavs
-#' @details This function aims to simplify the process of converting sound files that cannot be imported into R and/or homogenizing sound files. Problematic files can be determined using \code{\link{check_wavs}} or \code{\link{check_sels}}. The
+#' @details This function aims to simplify the process of converting sound files that cannot be imported into R and/or homogenizing sound files. Problematic files can be determined using \code{\link{check_sound_files}} or \code{\link{check_sels}}. The
 #' \code{\link{check_sels}} output can be directly input using the argument 'checksels'. Alternatively a vector of file
 #' names to be "fixed" can be provided (argument 'files'). If neither of those 2 are provided the function will convert
 #' all .wav sound files in the working directory to the specified sample rate/bit depth. Files are saved in a new directory
@@ -121,7 +119,7 @@ fix_wavs <- function(checksels = NULL, files = NULL, samp.rate = NULL, bit.depth
   # fix_bio_FUN <- function(x) {
   #
   #     # read waves
-  #     wv <- try(warbleR::read_wave(X = x, path = path), silent = TRUE)
+  #     wv <- try(warbleR::read_sound_file(X = x, path = path), silent = TRUE)
   #
   #     # downsample and filter if samp.rate different than mp3
   #     if(is(wv, "Wave") & !is.null(samp.rate))
@@ -183,13 +181,3 @@ fix_wavs <- function(checksels = NULL, files = NULL, samp.rate = NULL, bit.depth
 
   return(NULL)
 }
-
-
-##############################################################################################################
-#' alternative name for \code{\link{fix_wavs}}
-#'
-#' @keywords internal
-#' @details see \code{\link{fix_wavs}} for documentation. \code{\link{fixwavs}} will be deprecated in future versions.
-#' @export
-
-fixwavs <- fix_wavs
