@@ -1,9 +1,6 @@
 #' Calculates acoustic parameters at the song level
 #'
 #' \code{song_analysis} calculates descriptive statistics of songs or other higher levels of organization in the signals.
-#' @usage song_analysis(X = NULL, song_colm = "song",mean_colm = NULL, min_colm = NULL,
-#' max_colm = NULL, elm_colm = NULL, elm_fun = NULL, sd = FALSE, parallel = 1, pb = TRUE,
-#' na.rm = FALSE, weight = NULL)
 #' @param X 'selection_table', 'extended_selection_table' (created 'by.song') or data frame with the following columns: 1) "sound.files": name of the sound
 #' files, 2) "selec": number of the selections, 3) "start": start time of selections, 4) "end":
 #' end time of selections.
@@ -274,8 +271,13 @@ song_analysis <- function(X = NULL, song_colm = "song", mean_colm = NULL, min_co
   X$.....SONGX... <- paste(X$sound.files, X[, song_colm])
 
 
-
-
+  ## update progress message
+  if (pb) {
+    reset_onexit <- .update_progress("computing song features")
+    
+      on.exit(expr = eval(parse(text = reset_onexit)), add = TRUE)
+  }
+  
   # set clusters for windows OS
   if (Sys.info()[1] == "Windows" & parallel > 1) {
     cl <- parallel::makePSOCKcluster(getOption("cl.cores", parallel))
@@ -311,13 +313,3 @@ song_analysis <- function(X = NULL, song_colm = "song", mean_colm = NULL, min_co
 
   return(df)
 }
-
-
-##############################################################################################################
-#' alternative name for \code{\link{song_analysis}}
-#'
-#' @keywords internal
-#' @details see \code{\link{song_analysis}} for documentation. \code{\link{song_param}} will be deprecated in future versions.
-#' @export
-
-song_param <- song_analysis
